@@ -3,13 +3,10 @@ use strict;
 use warnings;
 use parent qw/Skype::Any::Object/;
 
-sub property { shift->_property('CALL', @_) }
-sub alter    { shift->_alter('CALL', @_) }
+sub property { shift->SUPER::property('CALL', @_) }
+sub alter    { shift->SUPER::alter('CALL', @_) }
 
-for my $property (qw/vaa_input_status/) {
-    no strict 'refs';
-    *{$property} = sub { $_[0]->_boolean($property) };
-}
+__PACKAGE__->_mk_boolean_property(qw/vaa_input_status/);
 
 1;
 __END__
@@ -20,14 +17,16 @@ Skype::Any::Object::Call - Call object for Skype::Any
 
 =head1 SYNOPSIS
 
-    use Skype::Any;
+  use Skype::Any;
 
-    my $skype = Skype::Any->new;
-    my $call = $skype->call($id);
+  my $skype = Skype::Any->new;
+  my $call = $skype->call($id);
 
 =head1 METHODS
 
-=head2 C<property>
+=over 4
+
+=item C<< $call->property($property[, $value]) >>
 
 =over 4
 
@@ -95,10 +94,8 @@ Skype::Any::Object::Call - Call object for Skype::Any
 
 =back
 
-=head2 C<alter>
+=item C<< $call->alter($action[, $value]) >>
 
-=head1 SEE ALSO
-
-L<Skype::Any::Object>
+=back
 
 =cut
